@@ -23,14 +23,18 @@
  * MA 02111-1307, USA.
  */
 
-#include "cbc-mac.h"
-
-#include "memxor.h"
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 #include <assert.h>
 #include <stdlib.h>
 #include <string.h>
 
+#include "cbc-mac.h"
+
+#include "memxor.h"
+
 void
 cbc_mac(void *ctx,
 	void (*f)(void *ctx,
