@@ -1,5 +1,5 @@
 /* aprep.c --- AP-REP functions.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -139,7 +139,7 @@ shishi_aprep_save (Shishi * handle, FILE * fh, Shishi_asn1 aprep)
  **/
 int
 shishi_aprep_to_file (Shishi * handle, Shishi_asn1 aprep,
-		      int filetype, char *filename)
+		      int filetype, const char *filename)
 {
   FILE *fh;
   int res;
@@ -219,7 +219,7 @@ shishi_aprep_read (Shishi * handle, FILE * fh, Shishi_asn1 * aprep)
  **/
 int
 shishi_aprep_from_file (Shishi * handle, Shishi_asn1 * aprep,
-			int filetype, char *filename)
+			int filetype, const char *filename)
 {
   int res;
   FILE *fh;
@@ -439,8 +439,7 @@ shishi_aprep_verify (Shishi * handle,
 {
   char *authenticatorctime;
   char *encapreppartctime;
-  int authenticatorcusec;
-  int encapreppartcusec;
+  uint32_t authenticatorcusec, encapreppartcusec;
   int res;
   int different;
 
