@@ -42,6 +42,7 @@ shishi_authenticator (Shishi * handle)
   Shishi_asn1 node = NULL;
   struct timeval tv;
   struct timezone tz;
+  uint32_t seqnr;
 
   node = shishi_asn1_authenticator (handle);
   if (!node)
@@ -71,7 +72,31 @@ shishi_authenticator (Shishi * handle)
   if (res != SHISHI_OK)
     goto error;
 
-  res = shishi_asn1_write (handle, node, "seq-number", NULL, 0);
+  /*
+   * For sequence numbers to adequately support the detection of
+   * replays they SHOULD be non-repeating, even across connection
+   * boundaries. The initial sequence number SHOULD be random and
+   * uniformly distributed across the full space of possible sequence
+   * numbers, so that it cannot be guessed by an attacker and so that
+   * it and the successive sequence numbers do not repeat other
+   * sequences.
+   */
+  shishi_randomize (handle, 0, &seqnr, sizeof(seqnr));
+
+  /* XXX remove once libtasn1 _asn1_convert_integer is fixed. */
+  seqnr &= 0x7FFFFFFF;
+
+  /*
+   * Implementation note: as noted before, some implementations omit
+   * the optional sequence number when its value would be zero.
+   * Implementations MAY accept an omitted sequence number when
+   * expecting a value of zero, and SHOULD NOT transmit an
+   * Authenticator with a initial sequence number of zero.
+   */
+  if (seqnr == 0)
+    seqnr++;
+
+  res = shishi_authenticator_seqnumber_set (handle, node, seqnr);
   if (res != SHISHI_OK)
     goto error;
 
@@ -160,7 +185,7 @@ shishi_authenticator_save (Shishi * handle,
  **/
 int
 shishi_authenticator_to_file (Shishi * handle, Shishi_asn1 authenticator,
-			      int filetype, char *filename)
+			      int filetype, const char *filename)
 {
   FILE *fh;
   int res;
@@ -243,7 +268,7 @@ shishi_authenticator_read (Shishi * handle,
  **/
 int
 shishi_authenticator_from_file (Shishi * handle, Shishi_asn1 * authenticator,
-				int filetype, char *filename)
+				int filetype, const char *filename)
 {
   int res;
   FILE *fh;
@@ -356,7 +381,7 @@ shishi_authenticator_client_set (Shishi * handle,
  * shishi_authenticator_ctime:
  * @handle: shishi handle as allocated by shishi_init().
  * @authenticator: Authenticator as allocated by shishi_authenticator().
- * @ctime: newly allocated zero-terminated character array with client time.
+ * @t: newly allocated zero-terminated character array with client time.
  *
  * Extract client time from Authenticator.
  *
@@ -364,16 +389,17 @@ shishi_authenticator_client_set (Shishi * handle,
  **/
 int
 shishi_authenticator_ctime (Shishi * handle,
-			    Shishi_asn1 authenticator, char **ctime)
+			    Shishi_asn1 authenticator,
+			    char **t)
 {
-  return shishi_time (handle, authenticator, "ctime", ctime);
+  return shishi_time (handle, authenticator, "ctime", t);
 }
 
 /**
  * shishi_authenticator_ctime_set:
  * @handle: shishi handle as allocated by shishi_init().
  * @authenticator: Authenticator as allocated by shishi_authenticator().
- * @ctime: string with generalized time value to store in Authenticator.
+ * @t: string with generalized time value to store in Authenticator.
  *
  * Store client time in Authenticator.
  *
@@ -381,12 +407,13 @@ shishi_authenticator_ctime (Shishi * handle,
  **/
 int
 shishi_authenticator_ctime_set (Shishi * handle,
-				Shishi_asn1 authenticator, char *ctime)
+				Shishi_asn1 authenticator,
+				const char *t)
 {
   int res;
 
   res = shishi_asn1_write (handle, authenticator, "ctime",
-			   ctime, GENERALIZEDTIME_TIME_LEN);
+			   t, GENERALIZEDTIME_TIME_LEN);
   if (res != SHISHI_OK)
     return res;
 
@@ -405,7 +432,8 @@ shishi_authenticator_ctime_set (Shishi * handle,
  **/
 int
 shishi_authenticator_cusec_get (Shishi * handle,
-				Shishi_asn1 authenticator, int *cusec)
+				Shishi_asn1 authenticator,
+				uint32_t *cusec)
 {
   int res;
 
@@ -428,7 +456,8 @@ shishi_authenticator_cusec_get (Shishi * handle,
  **/
 int
 shishi_authenticator_cusec_set (Shishi * handle,
-				Shishi_asn1 authenticator, int cusec)
+				Shishi_asn1 authenticator,
+				uint32_t cusec)
 {
   int res;
 
@@ -439,6 +468,78 @@ shishi_authenticator_cusec_set (Shishi * handle,
   return SHISHI_OK;
 }
 
+/**
+ * shishi_authenticator_seqnumber_get:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @authenticator: authenticator as allocated by shishi_authenticator().
+ * @seqnumber: output integer with sequence number field.
+ *
+ * Extract sequence number field from Authenticator.
+ *
+ * Return value: Returns %SHISHI_OK iff successful.
+ **/
+int
+shishi_authenticator_seqnumber_get (Shishi * handle,
+				    Shishi_asn1 authenticator,
+				    uint32_t * seqnumber)
+{
+  int res;
+
+  res = shishi_asn1_read_uint32 (handle, authenticator,
+				 "seq-number", seqnumber);
+  if (res != SHISHI_OK)
+    return res;
+
+  return res;
+}
+
+/**
+ * shishi_authenticator_seqnumber_remove:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @authenticator: authenticator as allocated by shishi_authenticator().
+ *
+ * Remove sequence number field in Authenticator.
+ *
+ * Return value: Returns %SHISHI_OK iff successful.
+ **/
+int
+shishi_authenticator_seqnumber_remove (Shishi * handle,
+				       Shishi_asn1 authenticator)
+{
+  int res;
+
+  res = shishi_asn1_write (handle, authenticator, "seq-number", NULL, 0);
+  if (res != SHISHI_OK)
+    return res;
+
+  return SHISHI_OK;
+}
+
+/**
+ * shishi_authenticator_seqnumber_set:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @authenticator: authenticator as allocated by shishi_authenticator().
+ * @seqnumber: integer with sequence number field to store in Authenticator.
+ *
+ * Store sequence number field in Authenticator.
+ *
+ * Return value: Returns %SHISHI_OK iff successful.
+ **/
+int
+shishi_authenticator_seqnumber_set (Shishi * handle,
+				    Shishi_asn1 authenticator,
+				    uint32_t seqnumber)
+{
+  int res;
+
+  res = shishi_asn1_write_uint32 (handle, authenticator,
+				  "seq-number", seqnumber);
+  if (res != SHISHI_OK)
+    return res;
+
+  return SHISHI_OK;
+}
+
 int
 shishi_authenticator_cname_get (Shishi * handle,
 				Shishi_asn1 authenticator,
@@ -653,12 +754,13 @@ shishi_authenticator_clear_authorizationdata (Shishi * handle,
 int
 shishi_authenticator_add_authorizationdata (Shishi * handle,
 					    Shishi_asn1 authenticator,
-					    int adtype,
-					    char *addata, size_t addatalen)
+					    int32_t adtype,
+					    const char *addata,
+					    size_t addatalen)
 {
   char *format;
   int res;
-  int i;
+  size_t i;
 
   res = shishi_asn1_write (handle, authenticator,
 			   "authorization-data", "NEW", 1);
@@ -705,13 +807,13 @@ shishi_authenticator_add_authorizationdata (Shishi * handle,
 int
 shishi_authenticator_authorizationdata (Shishi * handle,
 					Shishi_asn1 authenticator,
-					int *adtype,
+					int32_t *adtype,
 					char *addata, size_t * addatalen,
-					int nth)
+					size_t nth)
 {
   char *format;
   int res;
-  int i;
+  size_t i;
 
   res = shishi_asn1_number_of_elements (handle, authenticator,
 					"authorization-data", &i);
@@ -778,11 +880,6 @@ shishi_authenticator_get_subkey (Shishi * handle,
   int subkeytype;
   char *subkeyvalue;
   size_t subkeylen;
-  int n;
-
-  res = shishi_asn1_number_of_elements (handle, authenticator, "subkey", &n);
-  if (res != SHISHI_OK)
-    return res;
 
   res = shishi_asn1_read_int32 (handle, authenticator,
 				"subkey.keytype", &subkeytype);
