@@ -1,5 +1,5 @@
 /* cfg.h --- Configuration file functions.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -36,16 +36,16 @@ enum
   TICKET_LIFE_OPTION,
   RENEW_LIFE_OPTION,
   AUTHORIZATION_TYPES_OPTION,
-  VERBOSE_CRYPTO_NOICE_OPTION,
+  VERBOSE_CRYPTO_NOISE_OPTION,
   VERBOSE_CRYPTO_OPTION,
   VERBOSE_ASN1_OPTION,
-  VERBOSE_NOICE_OPTION,
+  VERBOSE_NOISE_OPTION,
   VERBOSE_OPTION,
   STRINGPROCESS_OPTION,
   THE_END
 };
 
-static char *const _shishi_opts[] = {
+static const char *_shishi_opts[] = {
   /* [DEFAULT_REALM_OPTION] =        */ "default-realm",
   /* [DEFAULT_PRINCIPAL_OPTION] =    */ "default-principal",
   /* [CLIENT_KDC_ETYPES_OPTION] =    */ "client-kdc-etypes",
@@ -56,10 +56,10 @@ static char *const _shishi_opts[] = {
   /* [TICKET_LIFE_OPTION] =          */ "ticket-life",
   /* [RENEW_LIFE_OPTION] =           */ "renew-life",
   /* [AUTHORIZATION_TYPES_OPTION] =  */ "authorization-types",
-  /* [VERBOSE_CRYPTO_NOICE_OPTION] = */ "verbose-crypto-noice",
+  /* [VERBOSE_CRYPTO_NOISE_OPTION] = */ "verbose-crypto-noise",
   /* [VERBOSE_CRYPTO_OPTION] =       */ "verbose-crypto",
   /* [VERBOSE_ASN1_OPTION] =         */ "verbose-asn1",
-  /* [VERBOSE_NOICE_OPTION] =        */ "verbose-noice",
+  /* [VERBOSE_NOISE_OPTION] =        */ "verbose-noise",
   /* [VERBOSE_OPTION] =              */ "verbose",
   /* [STRINGPROCESS_OPTION] =        */ "stringprocess",
   /* [THE_END] =                     */ NULL
@@ -141,7 +141,7 @@ shishi_cfg (Shishi * handle, char *option)
 	case TICKET_LIFE_OPTION:
 	  {
 	    time_t now = time (NULL);
-	    time_t then = get_date (value, &now);
+	    time_t then = shishi_get_date (value, &now);
 	    int diff = difftime (then, now);
 
 	    if (value && then != -1 && diff > 0)
@@ -161,7 +161,7 @@ shishi_cfg (Shishi * handle, char *option)
 	case RENEW_LIFE_OPTION:
 	  {
 	    time_t now = time (NULL);
-	    time_t then = get_date (value, &now);
+	    time_t then = shishi_get_date (value, &now);
 	    int diff = difftime (then, now);
 
 	    if (value && then != -1 && diff > 0)
@@ -239,8 +239,8 @@ shishi_cfg (Shishi * handle, char *option)
 	    ~0 & ~VERBOSES;
 	  break;
 
-	case VERBOSE_CRYPTO_NOICE_OPTION:
-	  handle->verbose |= SHISHI_VERBOSE_CRYPTO_NOICE;
+	case VERBOSE_CRYPTO_NOISE_OPTION:
+	  handle->verbose |= SHISHI_VERBOSE_CRYPTO_NOISE;
 	  break;
 
 	case VERBOSE_CRYPTO_OPTION:
@@ -251,8 +251,8 @@ shishi_cfg (Shishi * handle, char *option)
 	  handle->verbose |= SHISHI_VERBOSE_ASN1;
 	  break;
 
-	case VERBOSE_NOICE_OPTION:
-	  handle->verbose |= SHISHI_VERBOSE_NOICE;
+	case VERBOSE_NOISE_OPTION:
+	  handle->verbose |= SHISHI_VERBOSE_NOISE;
 	  break;
 
 	case -1:
@@ -474,10 +474,7 @@ shishi_cfg_default_userdirectory (Shishi * handle)
     {
       home = getenv ("HOME");
 
-      if (home == NULL)
-	home = "";
-
-      asprintf (&handle->userdirectory, "%s%s", home, BASE_DIR);
+      asprintf (&handle->userdirectory, "%s%s", home ? home : "", BASE_DIR);
     }
 
   return handle->userdirectory;
@@ -517,10 +514,7 @@ shishi_cfg_default_userfile (Shishi * handle)
     {
       home = getenv ("HOME");
 
-      if (home == NULL)
-	home = "";
-
-      asprintf (&handle->usercfgfile, "%s%s", home, USERCFG_FILE);
+      asprintf (&handle->usercfgfile, "%s%s", home ? home : "", USERCFG_FILE);
     }
 
   return handle->usercfgfile;
