@@ -1,5 +1,5 @@
 /* crypto.c --- Crypto functions.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -45,7 +45,7 @@ lcm (int a, int b)
 static void
 rot13 (Shishi * handle, char *in, char *out, int len)
 {
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       printf ("\t ;; rot 13 in:\n");
       _shishi_escapeprint (in, len);
@@ -85,7 +85,7 @@ rot13 (Shishi * handle, char *in, char *out, int len)
       out[1] = (in[1] & ~(0xFF & (0xFF << 3))) | (0xFF & (last << 3));
     }
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       printf ("\t ;; rot13 out:\n");
       _shishi_escapeprint (out, len);
@@ -648,32 +648,23 @@ shishi_cipher_defaultcksumtype (int32_t type)
   return -1;
 }
 
-static struct
+struct Cipher_aliases
 {
-  char *name;
+  const char *name;
   int type;
-} cipher_aliases[] =
-{
-  {
-  "des-crc", SHISHI_DES_CBC_CRC},
-  {
-  "des-md4", SHISHI_DES_CBC_MD4},
-  {
-  "des-md5", SHISHI_DES_CBC_MD5},
-  {
-  "des", SHISHI_DES_CBC_MD5},
-  {
-  "des3", SHISHI_DES3_CBC_HMAC_SHA1_KD},
-  {
-  "3des", SHISHI_DES3_CBC_HMAC_SHA1_KD},
-  {
-  "aes128", SHISHI_AES128_CTS_HMAC_SHA1_96},
-  {
-  "aes256", SHISHI_AES256_CTS_HMAC_SHA1_96},
-  {
-  "aes", SHISHI_AES256_CTS_HMAC_SHA1_96},
-  {
-  "arcfour", SHISHI_ARCFOUR_HMAC}
+};
+
+static struct Cipher_aliases cipher_aliases[] = {
+  {"des-crc", SHISHI_DES_CBC_CRC},
+  {"des-md4", SHISHI_DES_CBC_MD4},
+  {"des-md5", SHISHI_DES_CBC_MD5},
+  {"des", SHISHI_DES_CBC_MD5},
+  {"des3", SHISHI_DES3_CBC_HMAC_SHA1_KD},
+  {"3des", SHISHI_DES3_CBC_HMAC_SHA1_KD},
+  {"aes128", SHISHI_AES128_CTS_HMAC_SHA1_96},
+  {"aes256", SHISHI_AES256_CTS_HMAC_SHA1_96},
+  {"aes", SHISHI_AES256_CTS_HMAC_SHA1_96},
+  {"arcfour", SHISHI_ARCFOUR_HMAC}
 };
 
 /**
@@ -960,8 +951,8 @@ shishi_string_to_key (Shishi * handle,
  * shishi_random_to_key:
  * @handle: shishi handle as allocated by shishi_init().
  * @keytype: cryptographic encryption type, see Shishi_etype.
- * @random: input array with random data.
- * @randomlen: length of input array with random data.
+ * @rnd: input array with random data.
+ * @rndlen: length of input array with random data.
  * @outkey: allocated key handle that will contain new key.
  *
  * Derive key from random data for specified key type, and set the
@@ -972,8 +963,7 @@ shishi_string_to_key (Shishi * handle,
 int
 shishi_random_to_key (Shishi * handle,
 		      int32_t keytype,
-		      const char *random, size_t randomlen,
-		      Shishi_key * outkey)
+		      const char *rnd, size_t rndlen, Shishi_key * outkey)
 {
   Shishi_random_to_key_function random2key;
   int res;
@@ -984,8 +974,8 @@ shishi_random_to_key (Shishi * handle,
     {
       printf ("random_to_key (%s, random)\n", shishi_key_name (outkey));
       printf ("\t ;; random:\n");
-      _shishi_hexprint (random, randomlen);
-      _shishi_binprint (random, randomlen);
+      _shishi_hexprint (rnd, rndlen);
+      _shishi_binprint (rnd, rndlen);
     }
 
   random2key = _shishi_cipher_random_to_key (keytype);
@@ -996,7 +986,7 @@ shishi_random_to_key (Shishi * handle,
       return SHISHI_CRYPTO_ERROR;
     }
 
-  res = (*random2key) (handle, random, randomlen, outkey);
+  res = (*random2key) (handle, rnd, rndlen, outkey);
 
   if (VERBOSECRYPTO (handle))
     {
@@ -1176,7 +1166,7 @@ shishi_encrypt_ivupdate_etype (Shishi * handle,
 			       const char *in, size_t inlen,
 			       char **out, size_t * outlen)
 {
-  Shishi_encrypt_function encrypt;
+  Shishi_encrypt_function enc;
   int res;
 
   if (VERBOSECRYPTO (handle))
@@ -1196,16 +1186,16 @@ shishi_encrypt_ivupdate_etype (Shishi * handle,
 	}
     }
 
-  encrypt = _shishi_cipher_encrypt (etype);
-  if (encrypt == NULL)
+  enc = _shishi_cipher_encrypt (etype);
+  if (enc == NULL)
     {
       shishi_error_printf (handle, "Unsupported keytype %d",
 			   shishi_key_type (key));
       return SHISHI_CRYPTO_ERROR;
     }
 
-  res = (*encrypt) (handle, key, keyusage,
-		    iv, ivlen, ivout, ivoutlen, in, inlen, out, outlen);
+  res = (*enc) (handle, key, keyusage, iv, ivlen, ivout, ivoutlen,
+		in, inlen, out, outlen);
 
   if (VERBOSECRYPTO (handle))
     {
@@ -1790,7 +1780,7 @@ shishi_n_fold (Shishi * handle,
 
   lcmmn = lcm (m, n);
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       printf ("%d-fold (string)\n", n * 8);
       printf ("\t ;; string length %d bytes %d bits\n", m, m * 8);
@@ -1805,7 +1795,7 @@ shishi_n_fold (Shishi * handle,
   /* Replicate the input th the LCMMN length */
   for (i = 0; i < (lcmmn / m); i++)
     {
-      if (VERBOSECRYPTONOICE (handle))
+      if (VERBOSECRYPTONOISE (handle))
 	{
 	  printf ("\t ;; %d-th replication\n", i + 1);
 	  printf ("string = rot13(string)\n");
@@ -1817,7 +1807,7 @@ shishi_n_fold (Shishi * handle,
 
   memset (out, 0, n);		/* just in case */
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       printf ("\t ;; replicated string (length %d):\n", lcmmn);
       _shishi_hexprint (buf, lcmmn);
@@ -1832,7 +1822,7 @@ shishi_n_fold (Shishi * handle,
 
   for (i = 0; i < (lcmmn / n); i++)
     {
-      if (VERBOSECRYPTONOICE (handle))
+      if (VERBOSECRYPTONOISE (handle))
 	{
 	  printf ("\t ;; %d-th one's complement addition sum\n", i + 1);
 	  printf ("\t ;; sum:\n");
@@ -1846,7 +1836,7 @@ shishi_n_fold (Shishi * handle,
 
       ocadd (out, (char *) &buf[i * n], out, n);
 
-      if (VERBOSECRYPTONOICE (handle))
+      if (VERBOSECRYPTONOISE (handle))
 	{
 	  printf ("\t ;; sum:\n");
 	  _shishi_hexprint (out, n);
@@ -1854,7 +1844,7 @@ shishi_n_fold (Shishi * handle,
 	}
     }
 
-  if (VERBOSECRYPTONOICE (handle))
+  if (VERBOSECRYPTONOISE (handle))
     {
       printf ("\t ;; nfold\n");
       _shishi_hexprint (out, n);
@@ -1979,7 +1969,7 @@ shishi_dk (Shishi * handle,
 	   Shishi_key * key,
 	   const char *constant, size_t constantlen, Shishi_key * derivedkey)
 {
-  char random[MAX_RANDOM_LEN];
+  char rnd[MAX_RANDOM_LEN];
   int res;
 
   if (VERBOSECRYPTO (handle))
@@ -1996,13 +1986,13 @@ shishi_dk (Shishi * handle,
 
   shishi_key_type_set (derivedkey, shishi_key_type (key));
 
-  res = shishi_dr (handle, key, constant, constantlen, random,
+  res = shishi_dr (handle, key, constant, constantlen, rnd,
 		   shishi_key_length (derivedkey));
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_random_to_key (handle, shishi_key_type (derivedkey),
-			      random, shishi_key_length (derivedkey),
+			      rnd, shishi_key_length (derivedkey),
 			      derivedkey);
   if (res != SHISHI_OK)
     return res;
