@@ -140,22 +140,22 @@
 #define MAX_HASH_LEN 32
 #define MAX_CKSUM_LEN 32
 
-#define SHISHI_VERBOSE_NOICE		(1<<1)
+#define SHISHI_VERBOSE_NOISE		(1<<1)
 #define SHISHI_VERBOSE_ASN1		(1<<2)
 #define SHISHI_VERBOSE_CRYPTO		(1<<3)
-#define SHISHI_VERBOSE_CRYPTO_NOICE	(1<<4)
+#define SHISHI_VERBOSE_CRYPTO_NOISE	(1<<4)
 
 #define KRBTGT "krbtgt"
 #define PRINCIPAL_DELIMITER "/"
 
-#define VERBOSENOICE(h) (h->verbose & SHISHI_VERBOSE_NOICE)
+#define VERBOSENOISE(h) (h->verbose & SHISHI_VERBOSE_NOISE)
 #define VERBOSEASN1(h) (h->verbose & SHISHI_VERBOSE_ASN1)
 #define VERBOSECRYPTO(h) (h->verbose & SHISHI_VERBOSE_CRYPTO)
-#define VERBOSECRYPTONOICE(h) (h->verbose & SHISHI_VERBOSE_CRYPTO_NOICE)
+#define VERBOSECRYPTONOISE(h) (h->verbose & SHISHI_VERBOSE_CRYPTO_NOISE)
 #define VERBOSES (SHISHI_VERBOSE_ASN1 |		\
 		  SHISHI_VERBOSE_CRYPTO |	\
-		  SHISHI_VERBOSE_NOICE |	\
-		  SHISHI_VERBOSE_CRYPTO_NOICE)
+		  SHISHI_VERBOSE_NOISE |	\
+		  SHISHI_VERBOSE_CRYPTO_NOISE)
 #define VERBOSE(h) (h->verbose & ~VERBOSES)
 
 enum
