@@ -27,7 +27,7 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.14"
+#define SHISHI_VERSION "0.0.15"
 
 /* Error codes */
 typedef enum
@@ -609,7 +609,7 @@ extern int shishi_cfg_authorizationtype_set (Shishi * handle, char *value);
 extern const char *shishi_strerror (int err);
 extern const char *shishi_error (Shishi * handle);
 extern void shishi_error_clear (Shishi * handle);
-extern void shishi_error_set (Shishi * handle, const char *error);
+extern void shishi_error_set (Shishi * handle, const char *errstr);
 extern void shishi_error_printf (Shishi * handle, const char *format, ...);
 extern int shishi_outputtype (Shishi * handle);
 extern void shishi_set_outputtype (Shishi * handle, int type);
@@ -727,20 +727,21 @@ extern int shishi_tkt_serverrealm_set (Shishi_tkt * tkt,
 				       char *realm, char *server);
 extern int shishi_tkt_build (Shishi_tkt * tkt, Shishi_key * key);
 extern int shishi_tkt_lastreq (Shishi_tkt * tkt,
-			       char *lrtime, size_t * lrtimelen, int lrtype);
+			       char **lrtime, size_t * lrtimelen,
+			       int32_t lrtype);
 extern time_t shishi_tkt_lastreqc (Shishi_tkt * tkt, Shishi_lrtype lrtype);
 extern void shishi_tkt_lastreq_pretty_print (Shishi_tkt * tkt, FILE * fh);
 extern int shishi_tkt_authtime (Shishi_tkt * tkt,
-				char *authtime, size_t * authtimelen);
+				char **authtime, size_t * authtimelen);
 extern time_t shishi_tkt_authctime (Shishi_tkt * tkt);
 extern int shishi_tkt_starttime (Shishi_tkt * tkt,
-				 char *starttime, size_t * starttimelen);
+				 char **starttime, size_t * starttimelen);
 extern time_t shishi_tkt_startctime (Shishi_tkt * tkt);
 extern int shishi_tkt_endtime (Shishi_tkt * tkt,
-			       char *endtime, size_t * endtimelen);
+			       char **endtime, size_t * endtimelen);
 extern time_t shishi_tkt_endctime (Shishi_tkt * tkt);
 extern int shishi_tkt_renew_till (Shishi_tkt * tkt,
-				  char *renewtilltime, size_t * renewtilllen);
+				  char **renewtilltime, size_t * renewtilllen);
 extern time_t shishi_tkt_renew_tillc (Shishi_tkt * tkt);
 extern int shishi_tkt_keytype (Shishi_tkt * tkt, int32_t * etype);
 extern int32_t shishi_tkt_keytype_fast (Shishi_tkt * tkt);
@@ -756,9 +757,9 @@ extern int shishi_tkt_valid_now_p (Shishi_tkt * tkt);
 extern int shishi_tkt_expired_p (Shishi_tkt * tkt);
 extern int shishi_tkt_decrypt (Shishi_tkt * tkt, Shishi_key * key);
 extern void shishi_tkt_done (Shishi_tkt * tkt);
-extern int shishi_tkt_flags (Shishi_tkt * tkt, int *flags);
-extern int shishi_tkt_flags_set (Shishi_tkt * tkt, int flags);
-extern int shishi_tkt_flags_add (Shishi_tkt * tkt, int flag);
+extern int shishi_tkt_flags (Shishi_tkt * tkt, uint32_t *flags);
+extern int shishi_tkt_flags_set (Shishi_tkt * tkt, uint32_t flags);
+extern int shishi_tkt_flags_add (Shishi_tkt * tkt, uint32_t flag);
 extern int shishi_tkt_forwardable_p (Shishi_tkt * tkt);
 extern int shishi_tkt_forwarded_p (Shishi_tkt * tkt);
 extern int shishi_tkt_proxiable_p (Shishi_tkt * tkt);
@@ -869,16 +870,24 @@ extern int shishi_authenticator_client_set (Shishi * handle,
 					    const char *client);
 extern int shishi_authenticator_ctime (Shishi * handle,
 				       Shishi_asn1 authenticator,
-				       char **ctime);
+				       char **t);
 extern int shishi_authenticator_ctime_set (Shishi * handle,
 					   Shishi_asn1 authenticator,
-					   char *ctime);
+					   const char *t);
 extern int shishi_authenticator_cusec_get (Shishi * handle,
 					   Shishi_asn1 authenticator,
-					   int *cusec);
+					   uint32_t *cusec);
 extern int shishi_authenticator_cusec_set (Shishi * handle,
 					   Shishi_asn1 authenticator,
-					   int cusec);
+					   uint32_t cusec);
+extern int shishi_authenticator_seqnumber_get (Shishi * handle,
+					       Shishi_asn1 authenticator,
+					       uint32_t * seqnumber);
+extern int shishi_authenticator_seqnumber_remove (Shishi * handle,
+						  Shishi_asn1 authenticator);
+extern int shishi_authenticator_seqnumber_set (Shishi * handle,
+					       Shishi_asn1 authenticator,
+					       uint32_t seqnumber);
 extern int shishi_authenticator_cname_get (Shishi * handle,
 					   Shishi_asn1 authenticator,
 					   char *cname, size_t * cnamelen);
@@ -937,26 +946,27 @@ shishi_authenticator_clear_authorizationdata (Shishi * handle,
 extern int
 shishi_authenticator_add_authorizationdata (Shishi * handle,
 					    Shishi_asn1 authenticator,
-					    int adtype,
-					    char *addata, size_t addatalen);
+					    int32_t adtype,
+					    const char *addata,
+					    size_t addatalen);
 extern int
 shishi_authenticator_authorizationdata (Shishi * handle,
 					Shishi_asn1 authenticator,
-					int *adtype,
+					int32_t *adtype,
 					char *addata, size_t * addatalen,
-					int nth);
+					size_t nth);
 extern int shishi_authenticator_read (Shishi * handle, FILE * fh,
 				      Shishi_asn1 * authenticator);
 extern int shishi_authenticator_parse (Shishi * handle, FILE * fh,
 				       Shishi_asn1 * authenticator);
 extern int shishi_authenticator_from_file (Shishi * handle,
 					   Shishi_asn1 * authenticator,
-					   int filetype, char *filename);
+					   int filetype, const char *filename);
 extern int shishi_authenticator_print (Shishi * handle, FILE * fh,
 				       Shishi_asn1 authenticator);
 extern int shishi_authenticator_to_file (Shishi * handle,
 					 Shishi_asn1 authenticator,
-					 int filetype, char *filename);
+					 int filetype, const char *filename);
 extern int shishi_authenticator_save (Shishi * handle, FILE * fh,
 				      Shishi_asn1 authenticator);
 
@@ -1033,13 +1043,13 @@ extern int shishi_kdcreq_save (Shishi * handle, FILE * fh,
 extern int shishi_kdcreq_print (Shishi * handle, FILE * fh,
 				Shishi_asn1 kdcreq);
 extern int shishi_kdcreq_to_file (Shishi * handle, Shishi_asn1 kdcreq,
-				  int filetype, char *filename);
+				  int filetype, const char *filename);
 extern int shishi_kdcreq_parse (Shishi * handle, FILE * fh,
 				Shishi_asn1 * kdcreq);
 extern int shishi_kdcreq_read (Shishi * handle, FILE * fh,
 			       Shishi_asn1 * kdcreq);
 extern int shishi_kdcreq_from_file (Shishi * handle, Shishi_asn1 * kdcreq,
-				    int filetype, char *filename);
+				    int filetype, const char *filename);
 extern int shishi_asreq_cnamerealm_get (Shishi * handle, Shishi_asn1 kdcreq,
 					char *cnamerealm,
 					size_t * cnamerealmlen);
@@ -1136,8 +1146,8 @@ extern int shishi_enckdcreppart_flags_set (Shishi * handle,
 /* kdc.c */
 extern int shishi_as_derive_salt (Shishi * handle,
 				  Shishi_asn1 asreq,
-				  Shishi_asn1 asrep, char *salt,
-				  size_t * saltlen);
+				  Shishi_asn1 asrep,
+				  char **salt, size_t * saltlen);
 extern int shishi_tgs_process (Shishi * handle,
 			       Shishi_asn1 tgsreq,
 			       Shishi_asn1 tgsrep,
@@ -1178,13 +1188,13 @@ extern int shishi_kdcrep_save (Shishi * handle, FILE * fh,
 extern int shishi_kdcrep_print (Shishi * handle, FILE * fh,
 				Shishi_asn1 kdcrep);
 extern int shishi_kdcrep_to_file (Shishi * handle, Shishi_asn1 kdcrep,
-				  int filetype, char *filename);
+				  int filetype, const char *filename);
 extern int shishi_kdcrep_parse (Shishi * handle, FILE * fh,
 				Shishi_asn1 * kdcrep);
 extern int shishi_kdcrep_read (Shishi * handle, FILE * fh,
 			       Shishi_asn1 * kdcrep);
 extern int shishi_kdcrep_from_file (Shishi * handle, Shishi_asn1 * kdcrep,
-				    int filetype, char *filename);
+				    int filetype, const char *filename);
 extern int shishi_kdcrep_clear_padata (Shishi * handle, Shishi_asn1 kdcrep);
 extern int shishi_kdcrep_get_enc_part_etype (Shishi * handle,
 					     Shishi_asn1 kdcrep,
@@ -1222,13 +1232,13 @@ extern int shishi_krberror_print (Shishi * handle, FILE * fh,
 extern int shishi_krberror_save (Shishi * handle, FILE * fh,
 				 Shishi_asn1 krberror);
 extern int shishi_krberror_to_file (Shishi * handle, Shishi_asn1 krberror,
-				    int filetype, char *filename);
+				    int filetype, const char *filename);
 extern int shishi_krberror_parse (Shishi * handle, FILE * fh,
 				  Shishi_asn1 * krberror);
 extern int shishi_krberror_read (Shishi * handle, FILE * fh,
 				 Shishi_asn1 * krberror);
 extern int shishi_krberror_from_file (Shishi * handle, Shishi_asn1 * krberror,
-				      int filetype, char *filename);
+				      int filetype, const char *filename);
 extern int shishi_krberror_build (Shishi * handle, Shishi_asn1 krberror);
 extern int shishi_krberror_der (Shishi * handle,
 				Shishi_asn1 krberror,
@@ -1272,26 +1282,27 @@ extern int shishi_krberror_server_set (Shishi * handle,
 				       Shishi_asn1 krberror,
 				       const char *server);
 extern int shishi_krberror_ctime (Shishi * handle,
-				  Shishi_asn1 krberror, char **ctime);
+				  Shishi_asn1 krberror,
+				  char **t);
 extern int shishi_krberror_ctime_set (Shishi * handle,
 				      Shishi_asn1 krberror,
-				      const char *ctime);
+				      const char *t);
 extern int shishi_krberror_remove_ctime (Shishi * handle,
 					 Shishi_asn1 krberror);
 extern int shishi_krberror_cusec (Shishi * handle, Shishi_asn1 krberror,
-				  int *cusec);
+				  uint32_t *cusec);
 extern int shishi_krberror_cusec_set (Shishi * handle, Shishi_asn1 krberror,
-				      int cusec);
+				      uint32_t cusec);
 extern int shishi_krberror_remove_cusec (Shishi * handle,
 					 Shishi_asn1 krberror);
 extern int shishi_krberror_stime (Shishi * handle, Shishi_asn1 krberror,
-				  char **stime);
+				  char **t);
 extern int shishi_krberror_stime_set (Shishi * handle, Shishi_asn1 krberror,
-				      const char *stime);
+				      const char *t);
 extern int shishi_krberror_susec (Shishi * handle, Shishi_asn1 krberror,
-				  int *susec);
+				  uint32_t *susec);
 extern int shishi_krberror_susec_set (Shishi * handle, Shishi_asn1 krberror,
-				      int susec);
+				      uint32_t susec);
 extern int shishi_krberror_errorcode_set (Shishi * handle,
 					  Shishi_asn1 krberror,
 					  int errorcode);
@@ -1323,11 +1334,11 @@ extern const char *shishi_generalize_time (Shishi * handle, time_t t);
 extern const char *shishi_generalize_now (Shishi * handle);
 extern time_t shishi_generalize_ctime (Shishi * handle, const char *t);
 extern int shishi_time (Shishi * handle, Shishi_asn1 node,
-			const char *field, char **time);
+			const char *field, char **t);
 
 /* nettle.c, libgcrypt.c, ... */
 extern int shishi_randomize (Shishi * handle, int strong,
-			     char *data, size_t datalen);
+			     void *data, size_t datalen);
 extern int shishi_crc (Shishi * handle, const char *in, size_t inlen,
 		       char *out[4]);
 extern int shishi_md4 (Shishi * handle, const char *in, size_t inlen,
@@ -1376,7 +1387,8 @@ extern int shishi_string_to_key (Shishi * handle,
 				 const char *parameter, Shishi_key * outkey);
 extern int shishi_random_to_key (Shishi * handle,
 				 int32_t keytype,
-				 const char *random, size_t randomlen,
+				 const char *rnd,
+				 size_t rndlen,
 				 Shishi_key * outkey);
 extern int shishi_encrypt_ivupdate_etype (Shishi * handle,
 					  Shishi_key * key,
@@ -1656,7 +1668,7 @@ extern int shishi_ap_set_tktoptionsasn1usage (Shishi_ap * ap,
 					      Shishi_tkt * tkt,
 					      int options,
 					      Shishi_asn1 node,
-					      char *field,
+					      const char *field,
 					      int authenticatorcksumkeyusage,
 					      int authenticatorkeyusage);
 extern int shishi_ap_tktoptionsasn1usage (Shishi * handle,
@@ -1664,7 +1676,7 @@ extern int shishi_ap_tktoptionsasn1usage (Shishi * handle,
 					  Shishi_tkt * tkt,
 					  int options,
 					  Shishi_asn1 node,
-					  char *field,
+					  const char *field,
 					  int authenticatorcksumkeyusage,
 					  int authenticatorkeyusage);
 
@@ -1679,7 +1691,7 @@ shishi_ap_authenticator_cksumdata_set (Shishi_ap * ap,
 				       size_t authenticatorcksumdatalen);
 extern void
 shishi_ap_authenticator_cksumraw_set (Shishi_ap * ap,
-				      int32_t cksumtype,
+				      int32_t authenticatorcksumtype,
 				      const char *authenticatorcksumraw,
 				      size_t authenticatorcksumrawlen);
 extern int32_t shishi_ap_authenticator_cksumtype (Shishi_ap * ap);
@@ -1702,7 +1714,6 @@ extern int shishi_ap_req_process (Shishi_ap * ap, Shishi_key * key);
 extern int shishi_ap_req_process_keyusage (Shishi_ap * ap,
 					   Shishi_key * key,
 					   int32_t keyusage);
-extern int shishi_ap_req_build (Shishi_ap * ap);
 
 extern Shishi_asn1 shishi_ap_rep (Shishi_ap * ap);
 extern void shishi_ap_rep_set (Shishi_ap * ap, Shishi_asn1 aprep);
@@ -1732,8 +1743,6 @@ extern int shishi_key_type (Shishi_key * key);
 extern void shishi_key_type_set (Shishi_key * key, int32_t type);
 extern char *shishi_key_value (Shishi_key * key);
 extern void shishi_key_value_set (Shishi_key * key, const char *value);
-extern int shishi_key_value_set_random (Shishi_key * key,
-					char *random, size_t randomlen);
 extern const char *shishi_key_name (Shishi_key * key);
 extern size_t shishi_key_length (Shishi_key * key);
 extern int shishi_key_version (Shishi_key * key);
@@ -1755,7 +1764,8 @@ extern int shishi_key_from_base64 (Shishi * handle,
 				   const char *value, Shishi_key ** key);
 extern int shishi_key_from_random (Shishi * handle,
 				   int32_t type,
-				   const char *random, size_t randomlen,
+				   const char *rnd,
+				   size_t rndlen,
 				   Shishi_key ** outkey);
 extern int shishi_key_from_string (Shishi * handle,
 				   int32_t type,
@@ -1801,30 +1811,31 @@ extern int shishi_encapreppart_time_copy (Shishi * handle,
 					  Shishi_asn1 encapreppart,
 					  Shishi_asn1 authenticator);
 extern int shishi_encapreppart_ctime (Shishi * handle,
-				      Shishi_asn1 encapreppart, char **ctime);
+				      Shishi_asn1 encapreppart,
+				      char **t);
 extern int shishi_encapreppart_ctime_set (Shishi * handle,
 					  Shishi_asn1 encapreppart,
-					  char *ctime);
+					  const char *t);
 extern int shishi_encapreppart_cusec_get (Shishi * handle,
 					  Shishi_asn1 encapreppart,
-					  int *cusec);
+					  uint32_t *cusec);
 extern int shishi_encapreppart_cusec_set (Shishi * handle,
 					  Shishi_asn1 encapreppart,
-					  int cusec);
+					  uint32_t cusec);
 extern int shishi_encapreppart_print (Shishi * handle, FILE * fh,
 				      Shishi_asn1 encapreppart);
 extern int shishi_encapreppart_save (Shishi * handle, FILE * fh,
 				     Shishi_asn1 encapreppart);
 extern int shishi_encapreppart_to_file (Shishi * handle,
 					Shishi_asn1 encapreppart,
-					int filetype, char *filename);
+					int filetype, const char *filename);
 extern int shishi_encapreppart_read (Shishi * handle, FILE * fh,
 				     Shishi_asn1 * encapreppart);
 extern int shishi_encapreppart_parse (Shishi * handle, FILE * fh,
 				      Shishi_asn1 * encapreppart);
 extern int shishi_encapreppart_from_file (Shishi * handle,
 					  Shishi_asn1 * encapreppart,
-					  int filetype, char *filename);
+					  int filetype, const char *filename);
 extern int shishi_encapreppart_get_key (Shishi * handle,
 					Shishi_asn1 encapreppart,
 					int32_t * keytype,
@@ -1833,16 +1844,21 @@ extern int shishi_encapreppart_get_key (Shishi * handle,
 extern int shishi_encapreppart_seqnumber_get (Shishi * handle,
 					      Shishi_asn1 encapreppart,
 					      uint32_t * seqnumber);
+extern int shishi_encapreppart_seqnumber_remove (Shishi * handle,
+						 Shishi_asn1 encapreppart);
+extern int shishi_encapreppart_seqnumber_set (Shishi * handle,
+					      Shishi_asn1 encapreppart,
+					      uint32_t seqnumber);
 
 /* apreq.c */
 extern Shishi_asn1 shishi_apreq (Shishi * handle);
 extern int shishi_apreq_parse (Shishi * handle, FILE * fh,
 			       Shishi_asn1 * apreq);
 extern int shishi_apreq_from_file (Shishi * handle, Shishi_asn1 * apreq,
-				   int filetype, char *filename);
+				   int filetype, const char *filename);
 extern int shishi_apreq_print (Shishi * handle, FILE * fh, Shishi_asn1 apreq);
 extern int shishi_apreq_to_file (Shishi * handle, Shishi_asn1 apreq,
-				 int filetype, char *filename);
+				 int filetype, const char *filename);
 extern int shishi_apreq_read (Shishi * handle, FILE * fh,
 			      Shishi_asn1 * apreq);
 extern int shishi_apreq_save (Shishi * handle, FILE * fh, Shishi_asn1 apreq);
@@ -1855,17 +1871,17 @@ extern int shishi_apreq_add_authenticator (Shishi * handle, Shishi_asn1 apreq,
 					   Shishi_key * key, int keyusage,
 					   Shishi_asn1 authenticator);
 extern int shishi_apreq_options (Shishi * handle, Shishi_asn1 apreq,
-				 int *flags);
+				 uint32_t *flags);
 extern int shishi_apreq_use_session_key_p (Shishi * handle,
 					   Shishi_asn1 apreq);
 extern int shishi_apreq_mutual_required_p (Shishi * handle,
 					   Shishi_asn1 apreq);
 extern int shishi_apreq_options_set (Shishi * handle, Shishi_asn1 apreq,
-				     int options);
+				     uint32_t options);
 extern int shishi_apreq_options_add (Shishi * handle, Shishi_asn1 apreq,
-				     int option);
+				     uint32_t option);
 extern int shishi_apreq_options_remove (Shishi * handle, Shishi_asn1 apreq,
-					int option);
+					uint32_t option);
 extern int shishi_apreq_get_ticket (Shishi * handle, Shishi_asn1 apreq,
 				    Shishi_asn1 * ticket);
 extern int shishi_apreq_get_authenticator_etype (Shishi * handle,
@@ -1900,13 +1916,13 @@ extern Shishi_asn1 shishi_aprep (Shishi * handle);
 extern int shishi_aprep_print (Shishi * handle, FILE * fh, Shishi_asn1 aprep);
 extern int shishi_aprep_save (Shishi * handle, FILE * fh, Shishi_asn1 aprep);
 extern int shishi_aprep_to_file (Shishi * handle, Shishi_asn1 aprep,
-				 int filetype, char *filename);
+				 int filetype, const char *filename);
 extern int shishi_aprep_read (Shishi * handle, FILE * fh,
 			      Shishi_asn1 * aprep);
 extern int shishi_aprep_parse (Shishi * handle, FILE * fh,
 			       Shishi_asn1 * aprep);
 extern int shishi_aprep_from_file (Shishi * handle, Shishi_asn1 * aprep,
-				   int filetype, char *filename);
+				   int filetype, const char *filename);
 extern int shishi_aprep_decrypt (Shishi * handle, Shishi_asn1 aprep,
 				 Shishi_key * key, int keyusage,
 				 Shishi_asn1 * encapreppart);
@@ -1972,8 +1988,8 @@ extern int shishi_encticketpart_flags_set (Shishi * handle,
 					   int flags);
 extern int shishi_encticketpart_transited_set (Shishi * handle,
 					       Shishi_asn1 encticketpart,
-					       int trtype,
-					       char *trdata,
+					       int32_t trtype,
+					       const char *trdata,
 					       size_t trdatalen);
 extern int shishi_encticketpart_authtime_set (Shishi * handle,
 					      Shishi_asn1 encticketpart,
@@ -2002,7 +2018,7 @@ extern int shishi_safe_safe_der_set (Shishi_safe * safe,
 extern int shishi_safe_print (Shishi * handle, FILE * fh, Shishi_asn1 safe);
 extern int shishi_safe_save (Shishi * handle, FILE * fh, Shishi_asn1 safe);
 extern int shishi_safe_to_file (Shishi * handle, Shishi_asn1 safe,
-				int filetype, char *filename);
+				int filetype, const char *filename);
 extern int shishi_safe_parse (Shishi * handle, FILE * fh, Shishi_asn1 * safe);
 extern int shishi_safe_read (Shishi * handle, FILE * fh, Shishi_asn1 * safe);
 extern int shishi_safe_from_file (Shishi * handle, Shishi_asn1 * safe,
@@ -2046,7 +2062,7 @@ extern int shishi_priv_encprivpart_der_set (Shishi_priv * priv,
 extern int shishi_priv_print (Shishi * handle, FILE * fh, Shishi_asn1 priv);
 extern int shishi_priv_save (Shishi * handle, FILE * fh, Shishi_asn1 priv);
 extern int shishi_priv_to_file (Shishi * handle, Shishi_asn1 priv,
-				int filetype, char *filename);
+				int filetype, const char *filename);
 extern int shishi_priv_parse (Shishi * handle, FILE * fh, Shishi_asn1 * priv);
 extern int shishi_priv_read (Shishi * handle, FILE * fh, Shishi_asn1 * priv);
 extern int shishi_priv_from_file (Shishi * handle, Shishi_asn1 * priv,
@@ -2072,6 +2088,10 @@ extern int shishi_priv_process (Shishi_priv * priv, Shishi_key * key);
 extern int shishi_authorized_p (Shishi * handle,
 				Shishi_tkt * tkt, const char *authzname);
 extern int shishi_authorization_parse (const char *authorization);
+extern int shishi_authorize_strcmp (Shishi * handle, const char *principal,
+				    const char *authzname);
+extern int shishi_authorize_k5login (Shishi * handle, const char *principal,
+				     const char *authzname);
 
 /* pki.c */
 extern char *shishi_x509cert_default_file_guess (Shishi * handle);
@@ -2083,4 +2103,7 @@ extern void shishi_x509key_default_file_set (Shishi * handle,
 					     const char *x509keyfile);
 extern const char *shishi_x509key_default_file (Shishi * handle);
 
+/* utils.c */
+extern time_t shishi_get_date (const char *p, const time_t *now);
+
 #endif
