@@ -1,5 +1,5 @@
 /* tkts.c	Ticket set handling.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -44,10 +44,7 @@ shishi_tkts_default_file_guess (void)
 
   home = getenv ("HOME");
 
-  if (home == NULL)
-    home = "";
-
-  asprintf (&p, "%s%s", home, TICKET_FILE);
+  asprintf (&p, "%s%s", home ? home : "", TICKET_FILE);
 
   return p;
 }
@@ -656,7 +653,7 @@ shishi_tkts_find (Shishi_tkts * tkts, Shishi_tkts_hint * hint)
 {
   int i;
 
-  if (VERBOSENOICE (tkts->handle))
+  if (VERBOSENOISE (tkts->handle))
     {
       fprintf (stderr, "Searching tickets... ");
       if (hint->server)
@@ -920,7 +917,7 @@ shishi_tkts_get_tgt (Shishi_tkts * tkts, Shishi_tkts_hint * hint)
       return NULL;
     }
 
-  if (VERBOSENOICE (tkts->handle))
+  if (VERBOSENOISE (tkts->handle))
     {
       printf ("Received ticket granting ticket:\n");
       shishi_tkt_pretty_print (tgt, stdout);
@@ -987,7 +984,7 @@ shishi_tkts_get_tgs (Shishi_tkts * tkts,
       return NULL;
     }
 
-  if (VERBOSENOICE (tkts->handle))
+  if (VERBOSENOISE (tkts->handle))
     {
       printf ("Received ticket:\n");
       shishi_tkt_pretty_print (tkt, stdout);
