@@ -1,5 +1,5 @@
 /* kdc.c --- Process AS and TGS requests.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -35,7 +35,8 @@ asreq1 (Shishi_as * as)
   int rc;
   char *username = NULL, *servername = NULL, *realm = NULL;
   Shisa_principal server, user;
-  uint32_t sessionkeytype = -1, etype;
+  uint32_t sessionkeytype = -1;
+  int32_t etype;
   int i;
 
   /*
@@ -422,7 +423,7 @@ asreq1 (Shishi_as * as)
       goto fatal;
     }
 
-  if (arg.verbose_flag)
+  if (arg.verbose_given)
     {
       shishi_kdcreq_print (handle, stderr, shishi_as_req (as));
       shishi_encticketpart_print (handle, stderr,
@@ -892,7 +893,7 @@ tgsreq1 (Shishi_tgs * tgs)
       goto fatal;
     }
 
-  if (arg.verbose_flag)
+  if (arg.verbose_given)
     {
       puts ("KDC-REQ in:");
       shishi_kdcreq_print (handle, stderr, shishi_tgs_req (tgs));
