@@ -1,5 +1,5 @@
 /* shishi.c --- Kerberos 5 Command line tool.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -45,9 +45,6 @@
 /* Get set_program_name and program_name. */
 #include "progname.h"
 
-/* Get get_date. */
-#include "getdate.h"
-
 /* Get asprintf. */
 #include "vasprintf.h"
 
@@ -132,17 +129,20 @@ main (int argc, char *argv[])
     error (1, 0, "Could not read library options: %s\n",
 	   shishi_strerror (rc));
 
-  if (args.verbose_flag)
-    {
-      rc = shishi_cfg (sh, "verbose");
-      if (rc != SHISHI_OK)
-	error (EXIT_FAILURE, 0, "Could not make library verbose: %s\n",
-	       shishi_strerror (rc));
-    }
+  if (args.verbose_given > 0)
+    shishi_cfg (sh, "verbose");
+  if (args.verbose_given > 1)
+    shishi_cfg (sh, "verbose-noise");
+  if (args.verbose_given > 2)
+    shishi_cfg (sh, "verbose-asn1");
+  if (args.verbose_given > 3)
+    shishi_cfg (sh, "verbose-crypto");
+  if (args.verbose_given > 4)
+    shishi_cfg (sh, "verbose-crypto-noise");
 
   if (args.starttime_arg)
     {
-      starttime = get_date (args.starttime_arg, NULL);
+      starttime = shishi_get_date (args.starttime_arg, NULL);
       if (starttime == -1)
 	error (EXIT_FAILURE, 0, "Invalid --starttime date `%s'",
 	       args.starttime_arg);
@@ -152,7 +152,7 @@ main (int argc, char *argv[])
 
   if (args.endtime_arg)
     {
-      endtime = get_date (args.endtime_arg, &starttime);
+      endtime = shishi_get_date (args.endtime_arg, &starttime);
       if (endtime == -1)
 	error (EXIT_FAILURE, 0, "Invalid --endtime date `%s'",
 	       args.starttime_arg);
@@ -162,7 +162,7 @@ main (int argc, char *argv[])
 
   if (args.renew_till_arg)
     {
-      renew_till = get_date (args.renew_till_arg, &starttime);
+      renew_till = shishi_get_date (args.renew_till_arg, &starttime);
       if (renew_till == -1)
 	error (EXIT_FAILURE, 0, "Invalid --renew-till date `%s'",
 	       args.renew_till_arg);
@@ -203,7 +203,7 @@ main (int argc, char *argv[])
 				    args.server_name_arg))
 	    continue;
 
-	  if (args.verbose_flag)
+	  if (args.verbose_given)
 	    {
 	      printf ("Removing ticket:\n");
 	      shishi_tkt_pretty_print (shishi_tkts_nth
